@@ -17,16 +17,20 @@ Simply run this script in a directory containing a buildout.cfg.
 The script accepts buildout command-line options, so you can
 use the -c option to specify an alternate configuration file.
 
-$Id: bootstrap.py 65529 2008-05-23 13:24:43Z mustapha $
+$Id: bootstrap.py 65999 2008-06-01 17:16:06Z mustapha $
 """
 
-import os, shutil, sys, tempfile, urllib2
+import os
+import shutil
+import sys
+import tempfile
+import urllib2
 
 tmpeggs = tempfile.mkdtemp()
 
 ez = {}
-exec urllib2.urlopen('http://peak.telecommunity.com/dist/ez_setup.py'
-                     ).read() in ez
+ez_setup_url = 'http://peak.telecommunity.com/dist/ez_setup.py'
+exec urllib2.urlopen(ez_setup_url).read() in ez
 ez['use_setuptools'](to_dir=tmpeggs, download_delay=0)
 
 import pkg_resources
@@ -41,8 +45,7 @@ assert os.spawnle(
     '-c', cmd, '-mqNxd', tmpeggs, 'zc.buildout',
     dict(os.environ,
          PYTHONPATH=
-         ws.find(pkg_resources.Requirement.parse('setuptools')).location
-         ),
+         ws.find(pkg_resources.Requirement.parse('setuptools')).location),
     ) == 0
 
 ws.add_entry(tmpeggs)
